/************************************************************************
* File:        BLEND24.C
* Description: This file contians the Blending Map for 24/32-bpp video
*              modes. The Put Pixel routines that use this blending map
*              are located in GRAPHICS.C.
* Author:      Jesse Towner.
************************************************************************/


/* I N C L U D E S *****************************************************/


#include <limits.h>
#include <stdlib.h>
#include <string.h>
#include <conio.h>
#include <ctype.h>
#include <stdio.h>
#include <dos.h>

#include "graphics.h"
#include "color.h"
#include "trans.h"

#ifdef __cplusplus
extern "C" {
#endif


/* M A C R O S *******************************************************/


/* macro for constructing blending routines */
#define BLEND(n)                                                             \
 static unsigned int cdecl _GFX_Blend24_##n(unsigned int x1, unsigned int x2) \
 {                                                                           \
 unsigned int r1, g1, b1, r2, g2, b2, r, g, b;                               \
															  \
 r1 = (x1 >> 16) & 0xFF;                                                     \
 r2 = (x2 >> 16) & 0xFF;                                                     \
 r = (r1*(n*256/255) + r2*(256-(n*256/255))) / 256;                          \
															  \
 g1 = (x1 >> 8) & 0xFF;                                                      \
 g2 = (x2 >> 8) & 0xFF;                                                      \
 g = (g1*(n*256/255) + g2*(256-(n*256/255))) / 256;                          \
															  \
 b1 = x1 & 0xFF;                                                             \
 b2 = x2 & 0xFF;                                                             \
 b = (b1*(n*256/255) + b2*(256-(n*256/255))) / 256;                          \
															  \
 return (r << 16) | (g << 8) | b;                                            \
 }


/* F U N C T I O N S ***************************************************/


/* declare 256 interpolation functions (one for each alpha) */
BLEND(0)   BLEND(1)   BLEND(2)   BLEND(3)
BLEND(4)   BLEND(5)   BLEND(6)   BLEND(7)
BLEND(8)   BLEND(9)   BLEND(10)  BLEND(11)
BLEND(12)  BLEND(13)  BLEND(14)  BLEND(15)
BLEND(16)  BLEND(17)  BLEND(18)  BLEND(19)
BLEND(20)  BLEND(21)  BLEND(22)  BLEND(23)
BLEND(24)  BLEND(25)  BLEND(26)  BLEND(27)
BLEND(28)  BLEND(29)  BLEND(30)  BLEND(31)
BLEND(32)  BLEND(33)  BLEND(34)  BLEND(35)
BLEND(36)  BLEND(37)  BLEND(38)  BLEND(39)
BLEND(40)  BLEND(41)  BLEND(42)  BLEND(43)
BLEND(44)  BLEND(45)  BLEND(46)  BLEND(47)
BLEND(48)  BLEND(49)  BLEND(50)  BLEND(51)
BLEND(52)  BLEND(53)  BLEND(54)  BLEND(55)
BLEND(56)  BLEND(57)  BLEND(58)  BLEND(59)
BLEND(60)  BLEND(61)  BLEND(62)  BLEND(63)
BLEND(64)  BLEND(65)  BLEND(66)  BLEND(67)
BLEND(68)  BLEND(69)  BLEND(70)  BLEND(71)
BLEND(72)  BLEND(73)  BLEND(74)  BLEND(75)
BLEND(76)  BLEND(77)  BLEND(78)  BLEND(79)
BLEND(80)  BLEND(81)  BLEND(82)  BLEND(83)
BLEND(84)  BLEND(85)  BLEND(86)  BLEND(87)
BLEND(88)  BLEND(89)  BLEND(90)  BLEND(91)
BLEND(92)  BLEND(93)  BLEND(94)  BLEND(95)
BLEND(96)  BLEND(97)  BLEND(98)  BLEND(99)
BLEND(100) BLEND(101) BLEND(102) BLEND(103)
BLEND(104) BLEND(105) BLEND(106) BLEND(107)
BLEND(108) BLEND(109) BLEND(110) BLEND(111)
BLEND(112) BLEND(113) BLEND(114) BLEND(115)
BLEND(116) BLEND(117) BLEND(118) BLEND(119)
BLEND(120) BLEND(121) BLEND(122) BLEND(123)
BLEND(124) BLEND(125) BLEND(126) BLEND(127)
BLEND(128) BLEND(129) BLEND(130) BLEND(131)
BLEND(132) BLEND(133) BLEND(134) BLEND(135)
BLEND(136) BLEND(137) BLEND(138) BLEND(139)
BLEND(140) BLEND(141) BLEND(142) BLEND(143)
BLEND(144) BLEND(145) BLEND(146) BLEND(147)
BLEND(148) BLEND(149) BLEND(150) BLEND(151)
BLEND(152) BLEND(153) BLEND(154) BLEND(155)
BLEND(156) BLEND(157) BLEND(158) BLEND(159)
BLEND(160) BLEND(161) BLEND(162) BLEND(163)
BLEND(164) BLEND(165) BLEND(166) BLEND(167)
BLEND(168) BLEND(169) BLEND(170) BLEND(171)
BLEND(172) BLEND(173) BLEND(174) BLEND(175)
BLEND(176) BLEND(177) BLEND(178) BLEND(179)
BLEND(180) BLEND(181) BLEND(182) BLEND(183)
BLEND(184) BLEND(185) BLEND(186) BLEND(187)
BLEND(188) BLEND(189) BLEND(190) BLEND(191)
BLEND(192) BLEND(193) BLEND(194) BLEND(195)
BLEND(196) BLEND(197) BLEND(198) BLEND(199)
BLEND(200) BLEND(201) BLEND(202) BLEND(203)
BLEND(204) BLEND(205) BLEND(206) BLEND(207)
BLEND(208) BLEND(209) BLEND(210) BLEND(211)
BLEND(212) BLEND(213) BLEND(214) BLEND(215)
BLEND(216) BLEND(217) BLEND(218) BLEND(219)
BLEND(220) BLEND(221) BLEND(222) BLEND(223)
BLEND(224) BLEND(225) BLEND(226) BLEND(227)
BLEND(228) BLEND(229) BLEND(230) BLEND(231)
BLEND(232) BLEND(233) BLEND(234) BLEND(235)
BLEND(236) BLEND(237) BLEND(238) BLEND(239)
BLEND(240) BLEND(241) BLEND(242) BLEND(243)
BLEND(244) BLEND(245) BLEND(246) BLEND(247)
BLEND(248) BLEND(249) BLEND(250) BLEND(251)
BLEND(252) BLEND(253) BLEND(254) BLEND(255)


/* D A T A **********************************************************/


gfxAlphaBlendMap_t gfxAlphaBlendMap24 =
 {
	{
	_GFX_Blend24_0,   _GFX_Blend24_1,   _GFX_Blend24_2,   _GFX_Blend24_3,
	_GFX_Blend24_4,   _GFX_Blend24_5,   _GFX_Blend24_6,   _GFX_Blend24_7,
	_GFX_Blend24_8,   _GFX_Blend24_9,   _GFX_Blend24_10,  _GFX_Blend24_11,
	_GFX_Blend24_12,  _GFX_Blend24_13,  _GFX_Blend24_14,  _GFX_Blend24_15,
	_GFX_Blend24_16,  _GFX_Blend24_17,  _GFX_Blend24_18,  _GFX_Blend24_19,
	_GFX_Blend24_20,  _GFX_Blend24_21,  _GFX_Blend24_22,  _GFX_Blend24_23,
	_GFX_Blend24_24,  _GFX_Blend24_25,  _GFX_Blend24_26,  _GFX_Blend24_27,
	_GFX_Blend24_28,  _GFX_Blend24_29,  _GFX_Blend24_30,  _GFX_Blend24_31,
	_GFX_Blend24_32,  _GFX_Blend24_33,  _GFX_Blend24_34,  _GFX_Blend24_35,
	_GFX_Blend24_36,  _GFX_Blend24_37,  _GFX_Blend24_38,  _GFX_Blend24_39,
	_GFX_Blend24_40,  _GFX_Blend24_41,  _GFX_Blend24_42,  _GFX_Blend24_43,
	_GFX_Blend24_44,  _GFX_Blend24_45,  _GFX_Blend24_46,  _GFX_Blend24_47,
	_GFX_Blend24_48,  _GFX_Blend24_49,  _GFX_Blend24_50,  _GFX_Blend24_51,
	_GFX_Blend24_52,  _GFX_Blend24_53,  _GFX_Blend24_54,  _GFX_Blend24_55,
	_GFX_Blend24_56,  _GFX_Blend24_57,  _GFX_Blend24_58,  _GFX_Blend24_59,
	_GFX_Blend24_60,  _GFX_Blend24_61,  _GFX_Blend24_62,  _GFX_Blend24_63,
	_GFX_Blend24_64,  _GFX_Blend24_65,  _GFX_Blend24_66,  _GFX_Blend24_67,
	_GFX_Blend24_68,  _GFX_Blend24_69,  _GFX_Blend24_70,  _GFX_Blend24_71,
	_GFX_Blend24_72,  _GFX_Blend24_73,  _GFX_Blend24_74,  _GFX_Blend24_75,
	_GFX_Blend24_76,  _GFX_Blend24_77,  _GFX_Blend24_78,  _GFX_Blend24_79,
	_GFX_Blend24_80,  _GFX_Blend24_81,  _GFX_Blend24_82,  _GFX_Blend24_83,
	_GFX_Blend24_84,  _GFX_Blend24_85,  _GFX_Blend24_86,  _GFX_Blend24_87,
	_GFX_Blend24_88,  _GFX_Blend24_89,  _GFX_Blend24_90,  _GFX_Blend24_91,
	_GFX_Blend24_92,  _GFX_Blend24_93,  _GFX_Blend24_94,  _GFX_Blend24_95,
	_GFX_Blend24_96,  _GFX_Blend24_97,  _GFX_Blend24_98,  _GFX_Blend24_99,
	_GFX_Blend24_100, _GFX_Blend24_101, _GFX_Blend24_102, _GFX_Blend24_103,
	_GFX_Blend24_104, _GFX_Blend24_105, _GFX_Blend24_106, _GFX_Blend24_107,
	_GFX_Blend24_108, _GFX_Blend24_109, _GFX_Blend24_110, _GFX_Blend24_111,
	_GFX_Blend24_112, _GFX_Blend24_113, _GFX_Blend24_114, _GFX_Blend24_115,
	_GFX_Blend24_116, _GFX_Blend24_117, _GFX_Blend24_118, _GFX_Blend24_119,
	_GFX_Blend24_120, _GFX_Blend24_121, _GFX_Blend24_122, _GFX_Blend24_123,
	_GFX_Blend24_124, _GFX_Blend24_125, _GFX_Blend24_126, _GFX_Blend24_127,
	_GFX_Blend24_128, _GFX_Blend24_129, _GFX_Blend24_130, _GFX_Blend24_131,
	_GFX_Blend24_132, _GFX_Blend24_133, _GFX_Blend24_134, _GFX_Blend24_135,
	_GFX_Blend24_136, _GFX_Blend24_137, _GFX_Blend24_138, _GFX_Blend24_139,
	_GFX_Blend24_140, _GFX_Blend24_141, _GFX_Blend24_142, _GFX_Blend24_143,
	_GFX_Blend24_144, _GFX_Blend24_145, _GFX_Blend24_146, _GFX_Blend24_147,
	_GFX_Blend24_148, _GFX_Blend24_149, _GFX_Blend24_150, _GFX_Blend24_151,
	_GFX_Blend24_152, _GFX_Blend24_153, _GFX_Blend24_154, _GFX_Blend24_155,
	_GFX_Blend24_156, _GFX_Blend24_157, _GFX_Blend24_158, _GFX_Blend24_159,
	_GFX_Blend24_160, _GFX_Blend24_161, _GFX_Blend24_162, _GFX_Blend24_163,
	_GFX_Blend24_164, _GFX_Blend24_165, _GFX_Blend24_166, _GFX_Blend24_167,
	_GFX_Blend24_168, _GFX_Blend24_169, _GFX_Blend24_170, _GFX_Blend24_171,
	_GFX_Blend24_172, _GFX_Blend24_173, _GFX_Blend24_174, _GFX_Blend24_175,
	_GFX_Blend24_176, _GFX_Blend24_177, _GFX_Blend24_178, _GFX_Blend24_179,
	_GFX_Blend24_180, _GFX_Blend24_181, _GFX_Blend24_182, _GFX_Blend24_183,
	_GFX_Blend24_184, _GFX_Blend24_185, _GFX_Blend24_186, _GFX_Blend24_187,
	_GFX_Blend24_188, _GFX_Blend24_189, _GFX_Blend24_190, _GFX_Blend24_191,
	_GFX_Blend24_192, _GFX_Blend24_193, _GFX_Blend24_194, _GFX_Blend24_195,
	_GFX_Blend24_196, _GFX_Blend24_197, _GFX_Blend24_198, _GFX_Blend24_199,
	_GFX_Blend24_200, _GFX_Blend24_201, _GFX_Blend24_202, _GFX_Blend24_203,
	_GFX_Blend24_204, _GFX_Blend24_205, _GFX_Blend24_206, _GFX_Blend24_207,
	_GFX_Blend24_208, _GFX_Blend24_209, _GFX_Blend24_210, _GFX_Blend24_211,
	_GFX_Blend24_212, _GFX_Blend24_213, _GFX_Blend24_214, _GFX_Blend24_215,
	_GFX_Blend24_216, _GFX_Blend24_217, _GFX_Blend24_218, _GFX_Blend24_219,
	_GFX_Blend24_220, _GFX_Blend24_221, _GFX_Blend24_222, _GFX_Blend24_223,
	_GFX_Blend24_224, _GFX_Blend24_225, _GFX_Blend24_226, _GFX_Blend24_227,
	_GFX_Blend24_228, _GFX_Blend24_229, _GFX_Blend24_230, _GFX_Blend24_231,
	_GFX_Blend24_232, _GFX_Blend24_233, _GFX_Blend24_234, _GFX_Blend24_235,
	_GFX_Blend24_236, _GFX_Blend24_237, _GFX_Blend24_238, _GFX_Blend24_239,
	_GFX_Blend24_240, _GFX_Blend24_241, _GFX_Blend24_242, _GFX_Blend24_243,
	_GFX_Blend24_244, _GFX_Blend24_245, _GFX_Blend24_246, _GFX_Blend24_247,
	_GFX_Blend24_248, _GFX_Blend24_249, _GFX_Blend24_250, _GFX_Blend24_251,
	_GFX_Blend24_252, _GFX_Blend24_253, _GFX_Blend24_254, _GFX_Blend24_255
	}
 };


#ifdef __cplusplus
};
#endif

/* end of file */