/************************************************************************
* File:        TEST.C
* Description: The source to the test program.
* Author:      Jesse Towner.
************************************************************************/


/* I N C L U D E S *****************************************************/


#include <limits.h>
#include <stdlib.h>
#include <string.h>
#include <conio.h>
#include <ctype.h>
#include <stdio.h>
#include <dos.h>

#include "graphics.h"
#include "color.h"
#include "trans.h"
#include "pcx.h"

#ifdef __cplusplus
extern "C" {
#endif


/* D A T A *************************************************************/


gfxClut_t transTable;
gfxPalette_t palette;


/* F U N C T I O N S ***************************************************/


void TransCallback(int pos)
{
 if ((pos & 3) == 3) {
	printf("*");
	fflush(stdout);
	}
}


/* M A I N *************************************************************/


void main(void)
{
 unsigned char * buffer;
 gfxBitmap_t * image1;
 int x=0, y=0;
 int ch;

 if ((buffer = GFX_CreateBuffer()) == NULL) {
	printf("Couldn't allocate a double buffer!\n");
	return;
	}

 /* Load in the PCX image */
 if ((image1 = PCX_Load("pic1.pcx")) == NULL) {
	GFX_DestroyBuffer(buffer);
	printf("Couldn't load in pic1.pcx!\n");
	return;
	}

 memcpy(palette, image1->palette, sizeof(gfxPalette_t));

 /* Create the Translucency CLUT with an alpha of 128. */
 printf("Creating the Translucency color map:\n");
 printf("<................................................................>\r<");
 GFX_CreateTransTable(&transTable, palette, 128, &TransCallback);
 GFX_SetActiveTransTable(&transTable);

 /* Set the video mode */
 GFX_SetMode13h();
 GFX_SetPalette(image1->palette, 0, 255, true);

 /* Draw a translucent pixel */
 while (ch != 27) {
	if (kbhit())
		ch = getch();
	else ch = 0;
	if (ch == 75)
		x--;
	if (ch == 77)
		x++;
	if (ch == 72)
		y--;
	if (ch == 80)
		y++;

	GFX_ClrScr(buffer, 0);
	GFX_Rectangle(buffer, 5, 5, 80, 70, GFX_FindBestColor(palette, 63, 0, 0));
	GFX_PutPixelTransASM(buffer, x, y, GFX_FindBestColor(palette, 0, 0, 63));
	GFX_WaitForRetrace();
	GFX_BitBlt(gfxScreenPtr, buffer);
	}

 /* Draw a translucent rectangle */
 ch = 0;
 while (ch != 27) {
	if (kbhit())
		ch = getch();
	else ch = 0;
	if (ch == 75)
		x--;
	if (ch == 77)
		x++;
	if (ch == 72)
		y--;
	if (ch == 80)
		y++;

	GFX_ClrScr(buffer, 0);
	GFX_Rectangle(buffer, 5, 5, 80, 70, GFX_FindBestColor(palette, 63, 0, 0));
	GFX_Rectangle(buffer, 100, 100, 180, 170, GFX_FindBestColor(palette, 0, 0, 63));
	GFX_RectangleTransASM(buffer, x, y, x+50, y+50, GFX_FindBestColor(palette, 0, 63, 0));
	GFX_WaitForRetrace();
	GFX_BitBlt(gfxScreenPtr, buffer);
	}

 /* Draw a standard image */
 ch = 0;
 while (ch != 27) {
	if (kbhit())
		ch = getch();
	else ch = 0;
	if (ch == 75)
		x--;
	if (ch == 77)
		x++;
	if (ch == 72)
		y--;
	if (ch == 80)
		y++;

	GFX_ClrScr(buffer, 0);
	GFX_Rectangle(buffer, 5, 5, 80, 70, GFX_FindBestColor(palette, 63, 0, 0));
	GFX_Rectangle(buffer, 100, 100, 180, 170, GFX_FindBestColor(palette, 0, 0, 63));
	GFX_Rectangle(buffer, 60, 20, 90, 60, GFX_FindBestColor(palette, 0, 63, 0));
	GFX_PutImage(buffer, image1->surface, x, y, image1->width, image1->height);
	GFX_WaitForRetrace();
	GFX_BitBlt(gfxScreenPtr, buffer);
	}

 /* Draw a translucent image */
 ch = 0;
 while (ch != 27) {
	if (kbhit())
		ch = getch();
	else ch = 0;
	if (ch == 75)
		x--;
	if (ch == 77)
		x++;
	if (ch == 72)
		y--;
	if (ch == 80)
		y++;

	GFX_ClrScr(buffer, 0);
	GFX_Rectangle(buffer, 5, 5, 80, 70, GFX_FindBestColor(palette, 63, 0, 0));
	GFX_Rectangle(buffer, 100, 100, 180, 170, GFX_FindBestColor(palette, 0, 0, 63));
	GFX_Rectangle(buffer, 60, 20, 90, 60, GFX_FindBestColor(palette, 0, 63, 0));
	GFX_PutImageTransASM(buffer, image1->surface, x, y, image1->width, image1->height);
	GFX_WaitForRetrace();
	GFX_BitBlt(gfxScreenPtr, buffer);
	}

 GFX_SetTextMode();
 GFX_DestroyBitmap(image1);
 GFX_DestroyBuffer(buffer);
}


#ifdef __cplusplus
};
#endif

/* end of file */
