/************************************************************************
* File:        TRANS.C
* Description: The source to our graphics module.
* Author:      Jesse Towner.
************************************************************************/


/* I N C L U D E S *****************************************************/


#include <limits.h>
#include <stdlib.h>
#include <string.h>
#include <conio.h>
#include <ctype.h>
#include <stdio.h>
#include <dos.h>

#include "graphics.h"
#include "color.h"
#include "trans.h"

#ifdef __cplusplus
extern "C" {
#endif


/* D A T A *************************************************************/


/* Pointer to the active color lookup table */
gfxClut_t * gfxActiveClut;


/* F U N C T I O N S ***************************************************/


void GFX_SetActiveTransTable(gfxClut_t * clut)
/************************************************************************
* Function:    GFX_SetActiveTransTable
* Parameters:  clut - pointer to the clut to set as the active one
*
* Description: Sets the translucency clut that will be used for all of
*              the translucency operations in 256 color video modes.
************************************************************************/
{ gfxActiveClut = clut; }


void GFX_CreateTransTable(gfxClut_t * clut, gfxPalette_t pal, int alpha,
	void (* callback)(int pos))
/************************************************************************
* Function:    GFX_CreateTransTable
* Parameters:  clut     - pointer to the clut to fill with translucency data
*              pal      - palette to use when creating the table
*              alpha    - the alpha value to use when creating the table
*              callback - this is the callback function
*
* Description: Creates a translucency clut that can be used for 256 video
*              modes. If 'callback' is not NULL, then it will call the
*              function 256 times over the time it takes to make the table.
*              This can be used to deteremine how much of the table has been
*              completed and how much is still left to do as it can take a
*              bit of time to calculate. This callback function can be
*              used as a progress indicator.
************************************************************************/
{
 int index, index2;
 gfxRgb_t c;

 for (index=0; index<256; index++) {
	for (index2=0; index2<256; index2++) {
		/* Mix the two colors together based on the alpha */
		c.r = ((int)pal[index].r * alpha / 255) + ((int)pal[index2].r * (255 - alpha) / 255);
		c.g = ((int)pal[index].g * alpha / 255) + ((int)pal[index2].g * (255 - alpha) / 255);
		c.b = ((int)pal[index].b * alpha / 255) + ((int)pal[index2].b * (255 - alpha) / 255);

		/* Store the blended color into the translucency clut */
		clut->data[index][index2] = GFX_FindBestColor(pal, c.r, c.g, c.b);
		}

	/* Should we call the callback function? */
	if (callback)
		callback(index);
	}

}


#ifdef __cplusplus
};
#endif

/* end of file */